<?php
/**
 * Register the new widget classes here so that they show up in the widget list 
 */
function crb_load_widgets() {
	register_widget('Self_Twitter_Widget');
	register_widget('Self_Facebook_Widget');
}
add_action('widgets_init', 'crb_load_widgets');

/**
 * Displays a block with latest tweets from particular user
 */
class Self_Twitter_Widget extends Carbon_Widget {
	protected $form_options = array(
		'width' => 300
	);

	/**
	 * Constructor
	 */
	function __construct() {
		$this->setup(
			__('Self Twitter Widget', 'selftwo'),
			__('Displays a block with your latest tweets', 'selftwo'),
			array(
				Carbon_Field::factory('text', 'title', __('Widget Title', 'selftwo')),
				Carbon_Field::factory('text', 'twitter_user', __('Twitter Username', 'selftwo')),
				Carbon_Field::factory('text', 'load', __('How many tweets?', 'selftwo'))
					->set_default_value('3'),
				Carbon_Field::factory('text', 'button_text', __('Button Text (optional)', 'selftwo')),
				Carbon_Field::factory('text', 'button_url', __('Button URL (optional)', 'selftwo')),
				Carbon_Field::factory('select', 'new_window', __('Open button link in a new window?', 'selftwo'))
					->set_options(array(false=>'No',true=>'Yes'))
					->set_default_value(false)
			),
			'widget_social'
		);
	}

	/**
	 * Called when rendering the widget in the front-end
	 */
	function front_end($args, $instance) {
		
		extract($args);
		
		global $self_twitter_settings;
		
		if (ot_get_option('twitter_oauth_access_token') && ot_get_option('twitter_oauth_access_token_secret') && ot_get_option('twitter_consumer_key') && ot_get_option('twitter_consumer_secret')){
		
			$load = intval($instance['load']);
			$title = $instance['title'];
			$twitter_user = $instance['twitter_user'];
			$button_text = $instance['button_text'];
			$button_url = $instance['button_url'];
			$new_window = $instance['new_window'];
			
			?><div class="tweets-widget"><?php
				
				echo ($title ? $before_title.$title.$after_title : '');
				
				if ($button_url || $button_text) {
				
					?><a href="<?php echo $button_url; ?>"<?php if ($new_window){ ?>target="_blank"<?php } ?> class="widget-button"><?php echo $button_text; ?></a><?php
				
				} ?>
			
				<div class="tweets-container">
					
					<?php
					
					$url = 'https://api.twitter.com/1.1/statuses/user_timeline.json';
					$getfield = '?include_entities=true&include_rts=true&screen_name='.$twitter_user.'&count='.$load;
					$requestMethod = 'GET';
					$twitter = new TwitterAPIExchange($self_twitter_settings);
					$tweets = $twitter->setGetfield($getfield)
					          ->buildOauth($url, $requestMethod)
					          ->performRequest();
					          
					$tweets = json_decode($tweets);
						
					if (!empty($tweets)) {
						echo '<ul>';
						foreach ($tweets as $tweet) {
						
							?>
							<li>
								<span class="tweet_text"><?php echo wpautop(self_add_links(str_replace('&apos;', '\'', $tweet->text))); ?></span>
								<span class="tweet_time"><i class="fa fa-twitter"></i>&nbsp;<?php echo boxy_relativeTime($tweet->created_at); ?> <?php _e('via','garnish'); ?> <a href="http://twitter.com/<?php echo $twitter_user; ?>" target="_blank">@<?php echo $twitter_user; ?></a></span>
							</li>
							<?php
						}
						echo '</ul>';
					}
					?>
					
				</div>
			
			</div><?php

		} else {
			
			echo '<p style="color:#dd0000;"><strong>Important:</strong> You need to enter your Twitter Settings on the Theme Options panel before you can use this widget.</p>';
			
		}
		
	}
}

/**
 * Displays a block with latest tweets from particular user
 */
class Self_Facebook_Widget extends Carbon_Widget {
	protected $form_options = array(
		'width' => 300
	);

	/**
	 * Constructor
	 */
	function __construct() {
		$this->setup(
			__('Self Facebook Widget', 'selftwo'),
			__('Displays a block with your latest facebook feed', 'selftwo'),
			array(
				Carbon_Field::factory('text', 'title', __('Title', 'selftwo')),
				Carbon_Field::factory('text', 'facebook_id', __('Facebook Page ID', 'selftwo')),
				Carbon_Field::factory('text', 'load', __('How many posts?', 'selftwo'))
					->set_default_value('3'),
				Carbon_Field::factory('text', 'button_text', __('Button Text (optional)', 'selftwo')),
				Carbon_Field::factory('text', 'button_url', __('Button URL (optional)', 'selftwo')),
				Carbon_Field::factory('select', 'new_window', __('Open button link in a new window?', 'selftwo'))
					->set_options(array(false=>'No',true=>'Yes'))
					->set_default_value(false)
			),
			'widget_social'
		);
	}

	/**
	 * Called when rendering the widget in the front-end
	 */
	function front_end($args, $instance) {
		
		extract($args);
		
		if (ot_get_option('facebook_app_id') && ot_get_option('facebook_app_secret')){
		
			global $fb;
			$fb = new Facebook(array(
				'appId' => ot_get_option('facebook_app_id'),
				'secret' => ot_get_option('facebook_app_secret')
			));
			$fb->getAccessToken();
			
			$load = intval($instance['load']);
			$title = $instance['title'];
			$facebook_id = $instance['facebook_id'];
			$button_text = $instance['button_text'];
			$button_url = $instance['button_url'];
			$new_window = $instance['new_window'];
			
			?><div class="facebook-widget"><?php
				
				echo ($title ? $before_title.$title.$after_title : ''); ?>
				
				<?php if ($button_url || $button_text) {
				
					?><a href="<?php echo $button_url; ?>"<?php if ($new_window){ ?>target="_blank"<?php } ?> class="btn btn-small widget-button"><?php echo $button_text; ?></a><?php
				
				} ?>
				
				<ul>
					<?php
						
					$statuses = $fb->api('/' . $facebook_id . '/feed', array( 'limit' => $load, 'type' => 'message' ));
					
					if (!empty($statuses['data'])) {
						$temp_count = 0;
						foreach ($statuses['data'] as $s): $temp_count++;
							if ($temp_count <= $load){
							
								if ($s['type'] == 'photo'){
								
									if (isset($s['message'])){
										$message = $s['message'];
									} else {
										$message = $s['story'];
									}
						
									?>
									<li>
										<p><span class="tweet_text"><em><?php echo boxy_makeClickableLinks(boxy_char_shortalize($message)); ?></em><?php echo '<br /><strong><a href="'.$s['link'].'">View photo</a></strong>'; ?></span></p>
										<span class="tweet_time"><a href="http://facebook.com/<?php echo $s['id']; ?>"><?php _e('about','selftwo'); ?> <?php echo boxy_relativeTime($s['created_time'],true); ?> </a></span>
									</li>
									<?php
									
								
								} else {
									
									if (isset($s['message'])){
										$message = $s['message'];
									} else {
										$message = $s['story'];
									}
							
									?>
									<li>
										<p><span class="tweet_text"><?php echo boxy_makeClickableLinks(boxy_char_shortalize($message)); ?><?php if ($s['type'] == 'link'){ echo '<br /><a href="'.$s['link'].'">Click to view link</a>'; } ?></span></p>
										<span class="tweet_time"><a target="_blank" href="http://facebook.com/<?php echo $s['id']; ?>"><?php _e('about','selftwo'); ?> <?php echo boxy_relativeTime($s['created_time'],true); ?> &mdash; <?php _e('View on Facebook','selftwo'); ?></a></span>
									</li>
									<?php
								
								}
								
							} else {
								break;
							}
						endforeach;
					}
					?>
				</ul>
			
			</div><?php

		} else {
			
			echo '<p style="color:#dd0000;"><strong>Important:</strong> You need to enter your Facebook Settings on the Theme Options panel before you can use this widget.</p>';
			
		}
		
	}
}
